==> rheolef_5.92.orig.tar.gz: rheolef-5.92/nfem/tst/form_div_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
BINDIR="../bin"
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
GEODIR=${GEODIR-"../../../rheolef/nfem/data"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

COMPONENT="0 1"
P="1 r z r2 rz z2"
status=0
command="../bin/mkgeo_grid_2d 10 10 > square.geo"
echo "      $command"
eval $command > square.geo 2>/dev/null

for i_comp in $COMPONENT; do
  for p in $P; do
    command="./form_div_tst square -component $i_comp -monom $p"
    echo "      $command"
    eval $command >/dev/null 2>/dev/null
    if test $? -ne 0; then status=1; echo "        => *NO*"; fi
  done
done

command="/bin/rm -f square.geo"
echo "      $command"
eval $command

exit $status

==> rheolef_7.0.orig.tar.gz: rheolef-7.0/nfem/tst/form_div_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
BINDIR="../bin"
SRCDIR=${SRCDIR-"../../../rheolef/nfem/tst"}
GEODIR=${GEODIR-"../../../rheolef/nfem/data"}

RHEOLEF_BASIS_PATH=${RHEOLEF_BASIS_PATH-"../basis"}
RHEOLEF_NUMBERING_PATH=${RHEOLEF_NUMBERING_PATH-"../basis"}
RHEOLEF_FORM_ELEMENT_PATH=${RHEOLEF_FORM_ELEMENT_PATH-"../form_element"}
export RHEOLEF_BASIS_PATH
export RHEOLEF_NUMBERING_PATH
export RHEOLEF_FORM_ELEMENT_PATH

COMPONENT="0 1"
P="1 r z r2 rz z2"
status=0
command="../sbin/mkgeo_grid_2d 10 10 > square.geo"
echo "      $command"
eval $command > square.geo 2>/dev/null

for i_comp in $COMPONENT; do
  for p in $P; do
    command="./form_div_tst square -component $i_comp -monom $p"
    echo "      $command"
    eval $command >/dev/null 2>/dev/null
    if test $? -ne 0; then status=1; echo "        => *NO*"; fi
  done
done

command="/bin/rm -f square.geo"
echo "      $command"
eval $command

exit $status
